//********************************************************************
//*** POSIX/time.hh
//*** Copyright (c) 2003-2009 by Markus Winand <mws@fatalmind.com>
//*** $Id: time.hh,v 1.17 2009-03-02 14:16:43 mws Exp $
//********************************************************************

#ifndef POSIX_TIME_HH
#define POSIX_TIME_HH

#include <time.h>
#include <iosfwd>

#ifndef POSIX_TIMEFWD_HH
#include "timeFwd.hh"
#endif

#ifndef INCLUDED_THREAD_LOCK_HH
#include "Thread/Lock.hh"
#endif

//using namespace fatalmind;

namespace fatalmind {
namespace POSIX {

// forward declarations
template<class ThreadingModel>
bool operator<(const timespec<ThreadingModel>& lho, const int rho);

template<class ThreadingModel>
std::ostream& operator<<(std::ostream&, const timespec<ThreadingModel>&);


template<class ThreadingModel>
class timespec: public ::timespec {
	public:
		timespec();	
		timespec(float);
		timespec(time_t sec, long nsec);
		timespec(::timespec);	
		timespec(const timespec<ThreadingModel>& t);
		~timespec();

		timespec<ThreadingModel>& operator+=(const timespec<ThreadingModel>&);
		timespec<ThreadingModel>& operator-=(const timespec<ThreadingModel>&);
	

		operator float() const;

	friend 
		std::ostream& operator<< <>(std::ostream&, const timespec<ThreadingModel>&);
	friend 
		bool operator< <>(const timespec<ThreadingModel>& lho, const int rho);
	private:
		typedef typename ThreadingModel::FastLock lock_t;
		mutable lock_t _lk;
};



} // namespace POSIX
} // namespace fatalmind

#ifndef INCLUDED_THREAD_LOCK_HH
#include "Thread/Lock.hh"
#endif


#endif
