//********************************************************************
//*** ResourcePool/Resource.hh
//*** Copyright (c) 2003-2009 by Markus Winand <mws@fatalmind.com>
//*** $Id: Resource.hh,v 1.11 2009-03-02 14:16:44 mws Exp $
//********************************************************************
/*
This file is part of ResourcePool.

ResourcePool is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

ResourcePool is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with ResourcePool; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA */

#ifndef RESOURCEPOOL_RESOURCE_HH
#define RESOURCEPOOL_RESOURCE_HH

#include <string>

namespace fatalmind {

/**
 * The common base for all Resources which can be pooled within a ResourcePool.
 */
class Resource {
	public:
		virtual ~Resource() {
		}
		virtual bool precheck() = 0;
		virtual bool postcheck() = 0;
		virtual void close() = 0;
		virtual void fail_close() = 0;

		/** 
		 * Returns an unique ID for the resource within it's ResourcePool.
		 */
		virtual const std::string& getResourceID() const = 0;
};

} // namespace fatalmind

#endif
