//********************************************************************
//*** ResourcePool/SQL/RTSQLExecute.hh
//*** Copyright (c) 2003-2009 by Markus Winand <mws@fatalmind.com>
//*** $Id: RTSQLExecute.hh,v 1.24 2009-03-17 18:06:29 mws Exp $
//********************************************************************
/*
This file is part of ResourcePool.

ResourcePool is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

ResourcePool is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with ResourcePool; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA */

#ifndef RESOURCEPOOL_SQL_RTSQLEXECUTE_HH
#define RESOURCEPOOL_SQL_RTSQLEXECUTE_HH

#include "mm/gc_ptr.hh"
#include "ResourcePool/SQL/RTSQLCommand.hh"
#include "ResourcePool/SQL/Resource.hh"
#include "ResourcePool/SQL/RTCommandParameters.hh"
#include "ResourcePool/SQL/BindInterface.hh"
#include "ResourcePool/SQL/SQLStatement.hh"
#include "ResourcePool/ResourcePool.hh"

namespace fatalmind {
namespace SQL {

template<class TM> class RTSQLExecute_Impl;
template<class TM> class RTSQLBatch;

/** 
 * A command to issue a non-select statement against
 * an SQL database.
 * Automatically commits if not encapsulated into a
 * \link fatalmind::SQL::RTSQLTransaction Transaction\endlink Command.
 */
template<class TM>
class RTSQLExecute
: public RTSQLCommand<TM>
, public BindInterface
{
	public:
		/**
		 * Creates a new command to issue the specified SQL statement against 
		 * the passed ResourcePool.
		 */
		RTSQLExecute(const ResourcePool<ResourceType<TM> >& p, const SQLStatement& sql);
		RTSQLExecute(const RTSQLExecute<TM>& rho);
		virtual ~RTSQLExecute();
		
		template<typename T>
		void bind(const unsigned int pos, const T& val, bool nul = false);

		virtual void clearParameters();

		void execute(typename ResourceType<TM>::resource_t& hand);
		virtual void outputoperator(std::ostream&) const;

		virtual const Clone* getPlainSpecializedCommand() const;
	protected:
		virtual Clone* DoClone() const;

	private:
		typedef RTSQLExecute_Impl<TM> rimpl_t;
		gc_ptr<rimpl_t> _realSQLExecute;	

		typedef typename SQLFactory<TM>::databaseType_t databaseType_t;
		RTSQLExecute(); // hidden dfault ctor
};


} // namespace SQL
} // namespace fatalmind
#endif
