//********************************************************************
//*** ResourcePool/SQL/SQLStatement.cc
//*** Copyright (c) 2003-2009 by Markus Winand <mws@fatalmind.com>
//*** $Id: SQLStatement.cc,v 1.8 2009-03-22 14:01:48 mws Exp $
//********************************************************************
/*
This file is part of ResourcePool.

ResourcePool is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

ResourcePool is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with ResourcePool; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA */

//#include <algorithm>
#include <sstream>

#include "SQLStatement.hh"
#include "SQLParser.hh"


namespace fatalmind {
namespace SQL {

SQLStatement::SQLStatement(const std::string& s) 
: sql(s)
, fragments()
, parameters()
{
	SQLParser p(sql, *this);
}

SQLStatement::SQLStatement(const char* s) 
: sql(s)
, fragments()
, parameters()
{
	SQLParser p(sql, *this);
}
		
unsigned int SQLStatement::getParamCount() const {
	return parameters.size();
}

std::string SQLStatement::getNameFor(const int pos) const {
	return parameters.at(pos).getName();
}
		
int SQLStatement::getTypeFor(const int pos) const {
	return parameters.at(pos).getType();
}

const std::string& SQLStatement::getSQL() const {
	return sql;
}
	
const std::string& SQLStatement::getSQLFragment(const int pos) const {
	return fragments.at(pos);
}

const int SQLStatement::Parameter::UNKNOWN = 0;
const int SQLStatement::Parameter::CHAR    = 1;
const int SQLStatement::Parameter::INT     = 2;
const int SQLStatement::Parameter::FLOAT   = 3;

} // namespace sql
} // namespace fatalmind

