//********************************************************************
//*** ResourcePool/oracle/ResourcePoolInstances.cc
//*** Copyright (c) 2003-2009 by Markus Winand <mws@fatalmind.com>
//*** $Id: ResourcePoolInstances.cc,v 1.33 2009-03-09 08:12:44 mws Exp $
//********************************************************************
/*
This file is part of ResourcePool.

ResourcePool is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of 
the License, or (at your option) any later version.

ResourcePool is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with ResourcePool; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA */

#ifndef RESOURCEPOOL_RESOURCEPOOL_HH
#include "ResourcePool/ResourcePool.hh"
#endif

#include "ResourcePool/ResourcePool.cc"
#include "ResourcePool/BatchCommand.cc"

#include "OptimizedBatchCommand.cc"

#ifndef RESOURCEPOOL_ORACLE_RESOURCEPOOL_HH
#include "ResourcePool/oracle/ResourcePool.hh"
#endif

#ifndef RESOURCEPOOL_ORACLE_RESOURCE_HH
#include "ResourcePool/oracle/Resource.hh"
#endif

#ifndef CACHE_CACHE_HH
#include "cache/Cache.hh"
#endif

#include "cache/Cache.cc"

#include "Resource.cc"
#include "Factory.cc"

#include "SelectListMetaDataCache.hh"
#include "CommandInterface.hh"

#include "oracleType.hh"
#include "ResourcePool/SQL/Bind.cc"
#include "ResourcePool/SQL/BindOut.cc"

using namespace fatalmind;

namespace fatalmind {

template class Command<oracle::ResourceType<DefaultThreadedModel, oracle::SelectListMetaDataCache > >;
//template class Command<oracle::ResourceType<DefaultThreadedModel, oracle::SelectListMetaDataNopCache > >;

template class ResourcePool<ResourceType::oracle>;
template class oracleResource<DefaultThreadedModel >;
template class oracleFactory<DefaultThreadedModel, oracle::SelectListMetaDataCache>;
//template class BatchCommand<oracle::CommandInterface<DefaultThreadedModel, oracle::SelectListMetaDataCache> >;
//template class BatchCommand<oracle::CommandInterface<DefaultThreadedModel, oracle::SelectListMetaDataNopCache> >;


//template oracle::SelectListMetaDataCache<DefaultThreadedModel>::type;
template class Cache<std::string
        , oracle::SelectListMetaData
        , oracle::SelectListMetaDataCtor
        , LeastRecentlyUsedExpirationPolicy
        , DefaultThreadedModel>;

template class BatchCommand<Command<oracle::ResourceType<DefaultThreadedModel, oracle::SelectListMetaDataCache > > >;
//template class BatchCommand<Command<oracle::ResourceType<DefaultThreadedModel, oracle::SelectListMetaDataNopCache > > >;
template class oracle::OptimizedBatchCommand<Command<oracle::ResourceType<DefaultThreadedModel, oracle::SelectListMetaDataCache > > >;

template class
SQL::Bind<oracle::oracleType, oracle::oracleTypeImpl>;

template class
SQL::BindOut<oracle::oracleRefType, oracle::oracleRefTypeImpl>;

const std::string oracleHandles::LogConstants::OCIHandleAlloc("OCIHandleAlloc");
const std::string oracleHandles::LogConstants::OCIStmtPrepare("OCIStmtPrepare");
const std::string oracleHandles::LogConstants::OCIAttrGet("OCIAttrGet");
const std::string oracleHandles::LogConstants::OCIAttrGetType("OCIAttrGet/OCI_ATTR_DATA_TYPE");
const std::string oracleHandles::LogConstants::OCIAttrGetSize("OCIAttrGet/OCI_ATTR_DATA_SIZE");
const std::string oracleHandles::LogConstants::OCIStmtExecute("OCIStmtExecute");
const std::string oracleHandles::LogConstants::OCIBindByPos("OCIBindByPos");
const std::string oracleHandles::LogConstants::OCIBindArrayOfStruct("OCIBindArrayOfStruct");
const std::string oracleHandles::LogConstants::OCITransCommit("OCITransCommit");
const std::string oracleHandles::LogConstants::OCITransRollback("OCITransRollback");
const std::string oracleHandles::LogConstants::OCI_NODATA("OCI_NO_DATA");
const std::string oracleHandles::LogConstants::NODATA("NO DATA;");
const std::string oracleHandles::LogConstants::MOREDATA("MORE DATA;");
const std::string oracleHandles::LogConstants::ORA01422MSG("ORA-01422: exact fetch returns more than requested number of rows");
const std::string oracleHandles::LogConstants::ORA01422("ORA-01422");
const std::string oracleHandles::LogConstants::ORA99999("ORA-99999");
const std::string oracleHandles::LogConstants::EXACT("EXACT");
const std::string oracleHandles::LogConstants::IMPLICIT("IMPLICIT");
const std::string oracleHandles::LogConstants::SLMDC("SLMDC");
const std::string oracleHandles::LogConstants::EMPTY("");
const std::string oracleHandles::LogConstants::SEMICOLON(";");

} //namespace fatalmind
